@@ -1,6 +1,6 @@
 package Net::CLI::Interact::Transport::Role::ConnectCore;
 {
-  $Net::CLI::Interact::Transport::Role::ConnectCore::VERSION = '1.121570';
+  $Net::CLI::Interact::Transport::Role::ConnectCore::VERSION = '1.122010';
 }
 
 use Moose::Role;
@@ -11,6 +11,7 @@ sub connect_core {
     my $self = shift;
 
     if ($self->use_net_telnet_connection) {
+        my $app = shift; # unused
         return $self->_via_native(@_);
     }
     else {
@@ -20,8 +21,8 @@ sub connect_core {
 
 sub _via_native {
     my $self = shift;
-    my $t = Net::Telnet->new(Cmd_remove_mode => 1);
-    $t->open(Host => $self->runtime_options)
+    my $t = Net::Telnet->new(Cmd_remove_mode => 1, @_);
+    $t->open()
         or confess "failed to open Net::Telnet connection to target device.";
     return $t;
 }
