@@ -1,6 +1,6 @@
 package Net::CLI::Interact::Transport::Telnet;
 {
-  $Net::CLI::Interact::Transport::Telnet::VERSION = '1.121570';
+  $Net::CLI::Interact::Transport::Telnet::VERSION = '1.122010';
 }
 
 use Moose;
@@ -18,6 +18,20 @@ extends 'Net::CLI::Interact::Transport';
         required => 1,
     );
 
+    has 'port' => (
+        is => 'rw',
+        isa => 'Int',
+        required => 0,
+        default => 23,
+    );
+
+    has 'opts' => (
+        is => 'rw',
+        isa => 'ArrayRef[Any]',
+        required => 0,
+        default => sub { [] },
+    );
+
     use Moose::Util::TypeConstraints;
     coerce 'Net::CLI::Interact::Transport::Telnet::Options'
         => from 'HashRef[Any]'
@@ -26,7 +40,7 @@ extends 'Net::CLI::Interact::Transport';
 # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
 # allow native use of Net::Telnet on Unix
-if (Net::CLI::Interact::Transport::is_win32()) {
+if (not Net::CLI::Interact::Transport::is_win32()) {
     has '+use_net_telnet_connection' => ( default => 1 );
 }
 
@@ -41,15 +55,26 @@ sub _build_app {
     my $self = shift;
     confess "please pass location of plink.exe in 'app' parameter to new()\n"
         if $self->is_win32;
-    return 'telnet'; # unix
+    return 'Net::Telnet'; # unix, but unused
 }
 
 sub runtime_options {
     my $self = shift;
-    return (
-        ($self->is_win32 ? '-telnet' : ()),
-        $self->connect_options->host,
-    );
+    if ($self->is_win32) {
+        return (
+            '-telnet',
+            '-P', $self->connect_options->port,
+            @{$self->connect_options->opts},
+            $self->connect_options->host,
+        );
+    }
+    else {
+        return (
+            Host => $self->connect_options->host,
+            Port => $self->connect_options->port,
+            @{$self->connect_options->opts},
+        );
+    }
 }
 
 1;
@@ -66,7 +91,7 @@ Net::CLI::Interact::Transport::Telnet - TELNET based CLI connection
 
 =head1 VERSION
 
-version 1.121570
+version 1.122010
 
 =head1 DECRIPTION
 
@@ -94,11 +119,20 @@ command line. Supported attributes:
 Host name or IP address of the host to which the TELNET application is to
 connect.
 
-=item reap
+=item port
 
-Only used on Unix platforms, this installs a signal handler which attempts to
-reap the C<ssh> child process. Pass a true value to enable this feature only
-if you notice zombie processes are being left behind after use.
+Port number on the host which is listening for the TELNET connection.
+Defaults to 23.
+
+=item opts
+
+If you want to pass any other options to the Telnet application, then use
+this option, which should be an array reference.
+
+On Windows platforms, each item on the list will be passed to the C<plink.exe>
+application, separated by a single space character. On Unix platforms, the
+L<Net::Telnet> library is used for TELNET connections, so the list can be any
+options taken by its C<new()> constructor.
 
 =back
 
